# AI and ML Lab Programs

This package contains a collection of Python programs that implement various AI and ML algorithms.

## Installation

To install the package, you can use:

```bash
pip install aiml_lab
```
